searchData={"items":[{"type":"module","title":"Bildad","doc":"This module contains documentation for the Bildad Jobs Framework.\n\nThis framework has a queue (with priority) and it can work across multiple nodes.\n\n> **NOTE**: THIS FRAMEWORK DOES NOT GUARANTEE EXACTLY ONCE DELIVERY.\n\nIF YOU ARE LOOKING FOR A JOB SCHEDULING FRAMEWORK THAT GUARAENTEES EXACTLY ONCE DELIVERY, THIS IS NOT IT.\nTHIS FRAMEWORK ALSO DOES NOT GUARANTEE THAT A JOB WILL RUN EXACTLY ONE TIME.\n\nThis framework is intended to only for jobs that are Elixir code and that will be running in a group of nodes\nthat are NOT connected.","ref":"Bildad.html"},{"type":"module","title":"Database - Bildad","doc":"Bildad uses the following tables in the database:\n\n* `Job templates` are the definition of the jobs that are available to run. They contain the name of the Elixir \nmodule to run and they contain a json schema to validate the job context when a job is run. Job templates are \ncreated by the application and are used to create job queue entries when it is time to run a job.\n\n* `Job queue entries` are the jobs that should be run. They have a status of available or running. They are \ncreated by the application and are run by the job engine. If the job completes successfully the job queue entry is\ndeleted. If the job fails it will be retried up to the number of max retries specified in the queue entry. Once\nthe maximum number of retries is reached the entry is deleted from the queue.\n\n* `Job runs` are the occurances of a job that have run or are running. They are created by the job engine when \nit picks up an entry from the queue and tries to run it. Job runs may be successful or failed. Job runs are\nnot deleted from the database when they are done to serve as a history of what has run.","ref":"Bildad.html#module-database"},{"type":"module","title":"Modules - Bildad","doc":"The `Bildad.Job.JobConfig` module is responsible for holding the configuration of the job scheduling framework. \nIt holds the module for the database repository and other internal configuration values.\n\nThe `Bildad.Job.Jobs` module is responsible for querying for job templates, job queue entries, and job runs.\nIt also has functions for creating, updating, and deleting job templates.\n\nThe `Bildad.Job.JobEngine` module is responsible for running jobs. Jobs are enqueued in the job queue by the application\nand then run by the job engine. This module also expires jobs that have timed out and are not running on any nodes.\nThis is meant to be run on a single node at a time (the framework does NOT guarantee this). \nA load balancer can be used to send requests to balance the load across multiple nodes.\n\nThe `Bildad.Job.JobKiller` module is responsible for killing jobs that have run too long. It runs on each node.\nThis module is configured to run under a supervision tree, you do not need to programmatically call it.","ref":"Bildad.html#module-modules"},{"type":"module","title":"Error Handling - Bildad","doc":"Bildad has built in retries for jobs that fail.\n\nThere are three primary types of error handling in Bildad:\n\n* Jobs that fail are immediately marked as failed run in the `job_runs` table. If it is the last retry \nthen the job is removed from the queue. If it is not the last retry then the queue entry is updated to \nbe available.\n* Jobs that run past their timeout are killed by the `JobKiller` module ON THE NODE RUNNING THE JOB. \nThe job is marked as failed in the `job_runs` table. If it is not the last retry then the queue entry \nis updated to be available. If it is the last retry then the job is removed from the queue.\n* Jobs that fail and are no longer running on any node (so they cannot be killed) are marked as failed \nin the `job_runs` table after the expiration date.","ref":"Bildad.html#module-error-handling"},{"type":"module","title":"Name - Bildad","doc":"Why the name Bildad? Bildad is a character from the Bible. He was one of Job's friends.\n\nSee the `README.md` for more information.","ref":"Bildad.html#module-name"},{"type":"module","title":"Bildad.Job.JobConfig","doc":"Configuration for the Bildad job scheduling framework.","ref":"Bildad.Job.JobConfig.html"},{"type":"function","title":"Bildad.Job.JobConfig.new/2","doc":"Creates a new JobConfig struct for the provided database repository.\n\nPrefer this function over directly creating the struct as the struct internals may change over time.","ref":"Bildad.Job.JobConfig.html#new/2"},{"type":"module","title":"Bildad.Job.JobEngine","doc":"This module contains the logic for enqueuing, running, killing and expiring jobs in the Bildad job scheduling framework.","ref":"Bildad.Job.JobEngine.html"},{"type":"function","title":"Bildad.Job.JobEngine.complete_a_job/2","doc":"Used to mark a job as completed successfully.","ref":"Bildad.Job.JobEngine.html#complete_a_job/2"},{"type":"function","title":"Bildad.Job.JobEngine.enqueue_and_run_job/4","doc":"Enqueues a job and runs it immediately. \n\nThis should be used sparingly as it bypasses the priority of other jobs in the queue.","ref":"Bildad.Job.JobEngine.html#enqueue_and_run_job/4"},{"type":"function","title":"Bildad.Job.JobEngine.enqueue_job/4","doc":"Adds a job to the queue. The order it will be run in will be based on priority and resource availability.\n\nEach message contains a `job_context` which is a map of data that will be passed to the job module when it is run.\nThis job context must conform to the schema defined in the job template.","ref":"Bildad.Job.JobEngine.html#enqueue_job/4"},{"type":"function","title":"Bildad.Job.JobEngine.enqueue_job_and_trigger_engine/4","doc":"Enqueues a job and triggers the job engine to run immediately.\n\nIf there are other jobs ahead of this one in the queue that are higher priority, they will be run first.\n\nThis is the preferred over `enqueue_and_run_job` as it respects the priority of other jobs in the queue.\n\nTODO: This should make the same API call that the cron job makes and it should check to see if the job engine is already running before starting it.","ref":"Bildad.Job.JobEngine.html#enqueue_job_and_trigger_engine/4"},{"type":"function","title":"Bildad.Job.JobEngine.expire_a_job/2","doc":"Used when a job is not running on any node and the expiration time has been reached.","ref":"Bildad.Job.JobEngine.html#expire_a_job/2"},{"type":"function","title":"Bildad.Job.JobEngine.fail_a_job/3","doc":"Jobs that come to completion and are not successful are marked as failed.","ref":"Bildad.Job.JobEngine.html#fail_a_job/3"},{"type":"function","title":"Bildad.Job.JobEngine.find_elixir_process/1","doc":"Locates the Elixir process by the job identifier.\nIf the process is not running or is running on another node then nil is returned.","ref":"Bildad.Job.JobEngine.html#find_elixir_process/1"},{"type":"function","title":"Bildad.Job.JobEngine.get_counts/1","doc":"Utility function go get the number of successful jobs and the number of jobs that failed.","ref":"Bildad.Job.JobEngine.html#get_counts/1"},{"type":"function","title":"Bildad.Job.JobEngine.get_retry_count/2","doc":"The queue entry points to the current run which has its retry count.\nThis function increments that number by one OR it returns 0 if there is not a currently running job (which is\nthe initial state of an enqueued job).","ref":"Bildad.Job.JobEngine.html#get_retry_count/2"},{"type":"function","title":"Bildad.Job.JobEngine.kill_a_job/2","doc":"If the Elixir process is running on this node then it kills the process and updates the database record.\n\nIf not, nothing happens on this node. The other nodes should being runnig this function as well and the\nprocess will be stopped on one of them.\nIf the process is not running on any node the job will eventually expire when the expiration time is reached.\nThe `expire_a_job` function should be called to handle that case. (This is done by the job engine.)","ref":"Bildad.Job.JobEngine.html#kill_a_job/2"},{"type":"function","title":"Bildad.Job.JobEngine.launch_job_process/2","doc":"Launches the Elixir process for the job passing it the job context.\nIt registers the process with the job identifier so that it can be found later.","ref":"Bildad.Job.JobEngine.html#launch_job_process/2"},{"type":"function","title":"Bildad.Job.JobEngine.remove_job_from_queue/2","doc":"Removes a job from the queue. This is typically called when a job is completed or when a user wishes to no longer run the job.","ref":"Bildad.Job.JobEngine.html#remove_job_from_queue/2"},{"type":"function","title":"Bildad.Job.JobEngine.run_a_job/2","doc":"This function is called by the job scheduler to run a job.","ref":"Bildad.Job.JobEngine.html#run_a_job/2"},{"type":"function","title":"Bildad.Job.JobEngine.run_job_engine/1","doc":"This function is called by the job scheduler to run the job engine.\n\nThis should be called by a single cron job in your environment so that the engine is run on one node at a time.\n\nTHIS FUNCTION MUST NOT BE RUN INSIDE A TRANSACTION. \nThe jobs should run in isolation from each other.\nThe queue record should be marked as 'RUNNING' as quickly as possible.","ref":"Bildad.Job.JobEngine.html#run_job_engine/1"},{"type":"function","title":"Bildad.Job.JobEngine.stop_job_in_queue/2","doc":"This function is called by the job scheduler to stop a job that is currently running.\nThis ONLY updates the record in the database, it does NOT stop the elixir process.\nTo stop the Elixir process if it is still running then `kill_a_job` should be called.","ref":"Bildad.Job.JobEngine.html#stop_job_in_queue/2"},{"type":"function","title":"Bildad.Job.JobEngine.try_to_kill_process/1","doc":"Tries to kill the process by sending an exit signal.","ref":"Bildad.Job.JobEngine.html#try_to_kill_process/1"},{"type":"function","title":"Bildad.Job.JobEngine.validate_job_context/2","doc":"Each job has a schema that defines the shape of the data that will be passed to the job module when it is run.","ref":"Bildad.Job.JobEngine.html#validate_job_context/2"},{"type":"module","title":"Bildad.Job.JobKiller","doc":"The JobKiller module is responsible for killing jobs that have run too long.","ref":"Bildad.Job.JobKiller.html"},{"type":"function","title":"Bildad.Job.JobKiller.child_spec/1","doc":"Returns a specification to start this module under a supervisor.\n\n`arg` is passed as the argument to `Task.start_link/1` in the `:start` field\nof the spec.\n\nFor more information, see the `Supervisor` module,\nthe `Supervisor.child_spec/2` function and the `t:Supervisor.child_spec/0` type.","ref":"Bildad.Job.JobKiller.html#child_spec/1"},{"type":"function","title":"Bildad.Job.JobKiller.run/2","doc":"Checks for jobs that need to be killed ON THIS NODE and tries to kill them.","ref":"Bildad.Job.JobKiller.html#run/2"},{"type":"function","title":"Bildad.Job.JobKiller.start_link/1","doc":"Starts the JobKiller task with the provided options. This task should be run on each node.\n\nThe repo is required and is the database repository to use for job management.\nThe check time is the number of seconds between checks for jobs to kill. It is OPTIONAL and defaults to 60 seconds.","ref":"Bildad.Job.JobKiller.html#start_link/1"},{"type":"module","title":"Bildad.Job.JobQueueEntries","doc":"Manages job queue entries.","ref":"Bildad.Job.JobQueueEntries.html"},{"type":"function","title":"Bildad.Job.JobQueueEntries.get_job_queue_entry_for_identifier/2","doc":"Gets the job queue entry for the provided job run identifier. Returns nil if not found.","ref":"Bildad.Job.JobQueueEntries.html#get_job_queue_entry_for_identifier/2"},{"type":"function","title":"Bildad.Job.JobQueueEntries.get_number_of_jobs_in_the_queue/1","doc":"Gets the number of jobs currently in the queue.","ref":"Bildad.Job.JobQueueEntries.html#get_number_of_jobs_in_the_queue/1"},{"type":"function","title":"Bildad.Job.JobQueueEntries.get_queue_position_for_job_run_identifier/2","doc":"Gets the queue position for the provided job run identifier. Returns nil if not found.","ref":"Bildad.Job.JobQueueEntries.html#get_queue_position_for_job_run_identifier/2"},{"type":"function","title":"Bildad.Job.JobQueueEntries.list_all_jobs_in_the_queue/1","doc":"Lists all the jobs in the queue without pagination.","ref":"Bildad.Job.JobQueueEntries.html#list_all_jobs_in_the_queue/1"},{"type":"function","title":"Bildad.Job.JobQueueEntries.list_all_jobs_in_the_queue/3","doc":"Lists all the jobs in the queue with pagination.","ref":"Bildad.Job.JobQueueEntries.html#list_all_jobs_in_the_queue/3"},{"type":"function","title":"Bildad.Job.JobQueueEntries.list_jobs_for_status_in_the_queue/2","doc":"Lists all the jobs for the given status in the queue without pagination.","ref":"Bildad.Job.JobQueueEntries.html#list_jobs_for_status_in_the_queue/2"},{"type":"function","title":"Bildad.Job.JobQueueEntries.list_jobs_for_status_in_the_queue/4","doc":"Lists all the jobs for the given status in the queue with pagination (with the default page size if nil provided for the page size).","ref":"Bildad.Job.JobQueueEntries.html#list_jobs_for_status_in_the_queue/4"},{"type":"function","title":"Bildad.Job.JobQueueEntries.list_jobs_to_run_in_the_queue/1","doc":"Lists all the jobs that are available to run in the queue without pagination.","ref":"Bildad.Job.JobQueueEntries.html#list_jobs_to_run_in_the_queue/1"},{"type":"function","title":"Bildad.Job.JobQueueEntries.list_jobs_to_run_in_the_queue/3","doc":"Lists all the jobs that are available to run in the queue with pagination.","ref":"Bildad.Job.JobQueueEntries.html#list_jobs_to_run_in_the_queue/3"},{"type":"function","title":"Bildad.Job.JobQueueEntries.list_running_jobs_in_the_queue/1","doc":"Lists all the jobs that are running in the queue without pagination.","ref":"Bildad.Job.JobQueueEntries.html#list_running_jobs_in_the_queue/1"},{"type":"function","title":"Bildad.Job.JobQueueEntries.list_running_jobs_in_the_queue/3","doc":"Lists all the jobs that are running in the queue with pagination.","ref":"Bildad.Job.JobQueueEntries.html#list_running_jobs_in_the_queue/3"},{"type":"function","title":"Bildad.Job.JobQueueEntries.preload_job_queue_entries/2","doc":"","ref":"Bildad.Job.JobQueueEntries.html#preload_job_queue_entries/2"},{"type":"module","title":"Bildad.Job.JobQueueEntry","doc":"Database table for the job queue entries.","ref":"Bildad.Job.JobQueueEntry.html"},{"type":"function","title":"Bildad.Job.JobQueueEntry.changeset/2","doc":"","ref":"Bildad.Job.JobQueueEntry.html#changeset/2"},{"type":"module","title":"Bildad.Job.JobRun","doc":"Database table for job runs. This includes active and completed job runs.","ref":"Bildad.Job.JobRun.html"},{"type":"function","title":"Bildad.Job.JobRun.changeset/2","doc":"","ref":"Bildad.Job.JobRun.html#changeset/2"},{"type":"module","title":"Bildad.Job.JobRuns","doc":"Manages job runs.","ref":"Bildad.Job.JobRuns.html"},{"type":"function","title":"Bildad.Job.JobRuns.get_number_of_job_runs/1","doc":"Returns the number of job runs. (This is useful for pagination.)","ref":"Bildad.Job.JobRuns.html#get_number_of_job_runs/1"},{"type":"function","title":"Bildad.Job.JobRuns.list_all_job_runs/3","doc":"Lists all the job runs with pagination.","ref":"Bildad.Job.JobRuns.html#list_all_job_runs/3"},{"type":"function","title":"Bildad.Job.JobRuns.list_expired_jobs/1","doc":"Lists all the jobs that were running, have not been killed and have expired without pagination.","ref":"Bildad.Job.JobRuns.html#list_expired_jobs/1"},{"type":"function","title":"Bildad.Job.JobRuns.list_expired_jobs/3","doc":"Lists all the jobs that were running, have not been killed and have expired with pagination (with the default page size if nil provided as the page size).","ref":"Bildad.Job.JobRuns.html#list_expired_jobs/3"},{"type":"function","title":"Bildad.Job.JobRuns.list_job_runs_for_identifier/2","doc":"Lists all the job runs for the provided job run identifier without pagination.","ref":"Bildad.Job.JobRuns.html#list_job_runs_for_identifier/2"},{"type":"function","title":"Bildad.Job.JobRuns.list_job_runs_for_result/2","doc":"Lists all the jobs that have finished with the provided result without pagination.","ref":"Bildad.Job.JobRuns.html#list_job_runs_for_result/2"},{"type":"function","title":"Bildad.Job.JobRuns.list_job_runs_for_result/4","doc":"Lists all the jobs that have finished with the provided result with pagination (with the default page size if nil provided as the page size).","ref":"Bildad.Job.JobRuns.html#list_job_runs_for_result/4"},{"type":"function","title":"Bildad.Job.JobRuns.list_job_runs_to_kill/1","doc":"Lists all the jobs that are running and have timed out without pagination.","ref":"Bildad.Job.JobRuns.html#list_job_runs_to_kill/1"},{"type":"function","title":"Bildad.Job.JobRuns.list_job_runs_to_kill/3","doc":"Lists all the jobs that are running and have timed out with pagination (with the default page size if nil provided as the page size).","ref":"Bildad.Job.JobRuns.html#list_job_runs_to_kill/3"},{"type":"function","title":"Bildad.Job.JobRuns.preload_job_runs/2","doc":"","ref":"Bildad.Job.JobRuns.html#preload_job_runs/2"},{"type":"module","title":"Bildad.Job.JobTemplate","doc":"Database table for job templates. \n\nJob templates are the jobs that are available to be run by putting then in the queue.","ref":"Bildad.Job.JobTemplate.html"},{"type":"function","title":"Bildad.Job.JobTemplate.changeset/2","doc":"","ref":"Bildad.Job.JobTemplate.html#changeset/2"},{"type":"module","title":"Bildad.Job.JobTemplates","doc":"Manages job templates.","ref":"Bildad.Job.JobTemplates.html"},{"type":"function","title":"Bildad.Job.JobTemplates.create_job_template/2","doc":"Creates a new job template with the provided attributes.\n\nNote that the module_name should be a string version of the Elixir module name that will be used to run the job.\n\nNote that the job_context_schema should be a map that represents the schema of the context that will be passed to the job module. \nIt will be used to validate the context before running the job.","ref":"Bildad.Job.JobTemplates.html#create_job_template/2"},{"type":"function","title":"Bildad.Job.JobTemplates.delete_job_template/2","doc":"Deletes the provided job template.","ref":"Bildad.Job.JobTemplates.html#delete_job_template/2"},{"type":"function","title":"Bildad.Job.JobTemplates.list_active_job_templates/1","doc":"Lists all the active job templates without pagination.","ref":"Bildad.Job.JobTemplates.html#list_active_job_templates/1"},{"type":"function","title":"Bildad.Job.JobTemplates.list_active_job_templates/3","doc":"Lists all the active job templates with pagination (with the default page size if nil provided as the page size).","ref":"Bildad.Job.JobTemplates.html#list_active_job_templates/3"},{"type":"function","title":"Bildad.Job.JobTemplates.list_all_job_templates/1","doc":"Lists all the active job templates without pagination.","ref":"Bildad.Job.JobTemplates.html#list_all_job_templates/1"},{"type":"function","title":"Bildad.Job.JobTemplates.list_all_job_templates/3","doc":"Lists all the active job templates with pagination (with the default page size if nil provided as the page size).","ref":"Bildad.Job.JobTemplates.html#list_all_job_templates/3"},{"type":"function","title":"Bildad.Job.JobTemplates.list_inactive_job_templates/1","doc":"Lists all the inactive job templates without pagination.","ref":"Bildad.Job.JobTemplates.html#list_inactive_job_templates/1"},{"type":"function","title":"Bildad.Job.JobTemplates.list_inactive_job_templates/3","doc":"Lists all the inactive job templates with pagination (with the default page size if nil provided as the page size).","ref":"Bildad.Job.JobTemplates.html#list_inactive_job_templates/3"},{"type":"function","title":"Bildad.Job.JobTemplates.list_job_templates/1","doc":"Lists all the active job templates without pagination.","ref":"Bildad.Job.JobTemplates.html#list_job_templates/1"},{"type":"function","title":"Bildad.Job.JobTemplates.list_job_templates/3","doc":"Lists all the active job templates with pagination (with the default page size if nil provided as the page size).","ref":"Bildad.Job.JobTemplates.html#list_job_templates/3"},{"type":"function","title":"Bildad.Job.JobTemplates.update_job_template/3","doc":"Updates the provided job template with the provided attributes.","ref":"Bildad.Job.JobTemplates.html#update_job_template/3"},{"type":"module","title":"Bildad.Job.Jobs","doc":"The Jobs module is responsible for managing job templates, job queue entries, and job runs.","ref":"Bildad.Job.Jobs.html"},{"type":"function","title":"Bildad.Job.Jobs.create_job_template/2","doc":"","ref":"Bildad.Job.Jobs.html#create_job_template/2"},{"type":"function","title":"Bildad.Job.Jobs.delete_job_template/2","doc":"","ref":"Bildad.Job.Jobs.html#delete_job_template/2"},{"type":"function","title":"Bildad.Job.Jobs.get_job_queue_entry_for_identifier/2","doc":"","ref":"Bildad.Job.Jobs.html#get_job_queue_entry_for_identifier/2"},{"type":"function","title":"Bildad.Job.Jobs.get_number_of_job_runs/1","doc":"","ref":"Bildad.Job.Jobs.html#get_number_of_job_runs/1"},{"type":"function","title":"Bildad.Job.Jobs.get_number_of_jobs_in_the_queue/1","doc":"","ref":"Bildad.Job.Jobs.html#get_number_of_jobs_in_the_queue/1"},{"type":"function","title":"Bildad.Job.Jobs.get_queue_position_for_job_run_identifier/2","doc":"","ref":"Bildad.Job.Jobs.html#get_queue_position_for_job_run_identifier/2"},{"type":"function","title":"Bildad.Job.Jobs.list_active_job_templates/1","doc":"","ref":"Bildad.Job.Jobs.html#list_active_job_templates/1"},{"type":"function","title":"Bildad.Job.Jobs.list_active_job_templates/3","doc":"","ref":"Bildad.Job.Jobs.html#list_active_job_templates/3"},{"type":"function","title":"Bildad.Job.Jobs.list_all_job_runs/3","doc":"","ref":"Bildad.Job.Jobs.html#list_all_job_runs/3"},{"type":"function","title":"Bildad.Job.Jobs.list_all_job_templates/1","doc":"","ref":"Bildad.Job.Jobs.html#list_all_job_templates/1"},{"type":"function","title":"Bildad.Job.Jobs.list_all_job_templates/3","doc":"","ref":"Bildad.Job.Jobs.html#list_all_job_templates/3"},{"type":"function","title":"Bildad.Job.Jobs.list_all_jobs_in_the_queue/1","doc":"","ref":"Bildad.Job.Jobs.html#list_all_jobs_in_the_queue/1"},{"type":"function","title":"Bildad.Job.Jobs.list_all_jobs_in_the_queue/3","doc":"","ref":"Bildad.Job.Jobs.html#list_all_jobs_in_the_queue/3"},{"type":"function","title":"Bildad.Job.Jobs.list_expired_jobs/1","doc":"","ref":"Bildad.Job.Jobs.html#list_expired_jobs/1"},{"type":"function","title":"Bildad.Job.Jobs.list_expired_jobs/3","doc":"","ref":"Bildad.Job.Jobs.html#list_expired_jobs/3"},{"type":"function","title":"Bildad.Job.Jobs.list_inactive_job_templates/1","doc":"","ref":"Bildad.Job.Jobs.html#list_inactive_job_templates/1"},{"type":"function","title":"Bildad.Job.Jobs.list_inactive_job_templates/3","doc":"","ref":"Bildad.Job.Jobs.html#list_inactive_job_templates/3"},{"type":"function","title":"Bildad.Job.Jobs.list_job_runs_for_identifier/2","doc":"","ref":"Bildad.Job.Jobs.html#list_job_runs_for_identifier/2"},{"type":"function","title":"Bildad.Job.Jobs.list_job_runs_for_result/2","doc":"","ref":"Bildad.Job.Jobs.html#list_job_runs_for_result/2"},{"type":"function","title":"Bildad.Job.Jobs.list_job_runs_for_result/4","doc":"","ref":"Bildad.Job.Jobs.html#list_job_runs_for_result/4"},{"type":"function","title":"Bildad.Job.Jobs.list_job_runs_to_kill/1","doc":"","ref":"Bildad.Job.Jobs.html#list_job_runs_to_kill/1"},{"type":"function","title":"Bildad.Job.Jobs.list_job_runs_to_kill/3","doc":"","ref":"Bildad.Job.Jobs.html#list_job_runs_to_kill/3"},{"type":"function","title":"Bildad.Job.Jobs.list_job_templates/1","doc":"","ref":"Bildad.Job.Jobs.html#list_job_templates/1"},{"type":"function","title":"Bildad.Job.Jobs.list_job_templates/3","doc":"","ref":"Bildad.Job.Jobs.html#list_job_templates/3"},{"type":"function","title":"Bildad.Job.Jobs.list_jobs_for_status_in_the_queue/2","doc":"","ref":"Bildad.Job.Jobs.html#list_jobs_for_status_in_the_queue/2"},{"type":"function","title":"Bildad.Job.Jobs.list_jobs_for_status_in_the_queue/4","doc":"","ref":"Bildad.Job.Jobs.html#list_jobs_for_status_in_the_queue/4"},{"type":"function","title":"Bildad.Job.Jobs.list_jobs_to_run_in_the_queue/1","doc":"","ref":"Bildad.Job.Jobs.html#list_jobs_to_run_in_the_queue/1"},{"type":"function","title":"Bildad.Job.Jobs.list_jobs_to_run_in_the_queue/3","doc":"","ref":"Bildad.Job.Jobs.html#list_jobs_to_run_in_the_queue/3"},{"type":"function","title":"Bildad.Job.Jobs.list_running_jobs_in_the_queue/1","doc":"","ref":"Bildad.Job.Jobs.html#list_running_jobs_in_the_queue/1"},{"type":"function","title":"Bildad.Job.Jobs.list_running_jobs_in_the_queue/3","doc":"","ref":"Bildad.Job.Jobs.html#list_running_jobs_in_the_queue/3"},{"type":"function","title":"Bildad.Job.Jobs.update_job_template/3","doc":"","ref":"Bildad.Job.Jobs.html#update_job_template/3"},{"type":"task","title":"mix bildad.install","doc":"Mix task to install the Bildad Jobs Framework into an application.","ref":"Mix.Tasks.Bildad.Install.html"},{"type":"function","title":"Mix.Tasks.Bildad.Install.run/1","doc":"Requires the `--application` name you want to install the Bildad Jobs Framework into.\n\nIt will install:\n* a database migration to create the necessary tables\n* a controller to run the job engine\n\nYou must manually add:\n* an entry in your router.ex file to route to the controller\n* a supervised child in your application.ex file to run the job killer task\n\nYou must also\n* set up a cron job to periodically call the job engine controller.","ref":"Mix.Tasks.Bildad.Install.html#run/1"},{"type":"extras","title":"Bildad","doc":"# Bildad\n\nFramework for running async jobs in an Elixir LiveView application.\n\nBildad is designed to run in a cluster of nodes that are NOT connected but share the same database.\n\nA JobKiller application runs on each node looking for jobs to kill on that node.\n\nA controller listens for requests to run the engine so that jobs will be started on ONE node.\n\nJobs that time out will eventually be killed. Jobs that die but are not killed will be expired.\n\nA message with a configurable number of retries is put in the job queue to run a job. When the job is completed, killed or expired it is removed from the queue table. Entries in the queue can have the following status:\n\n* AVAILABLE\n* RUNNING\n\nAfter the maximum number of retries messages are removed from the jobs queue.\n\nEach run of a job in the message queue is stored in the `job runs` table. It contains the retry number and information about how long the job took along with the following:\n\n* status (RUNNING, DONE)\n* result (SUCCEEDED, FAILED)\n* reason (text description of why a run failed)","ref":"readme.html"},{"type":"extras","title":"Installation - Bildad","doc":"If [available in Hex](https://hex.pm/docs/publish), the package can be installed\nby adding `bildad` to your list of dependencies in `mix.exs`:\n\n```elixir\ndef deps do\n  [\n    {:bildad, \"~> 0.1.0\"}\n  ]\nend\n```\n\nRun the mix task to install the necessary migration and controller. \nBe sure to replace `my_app_name` with the name of your application.\n\n```bash\nmix bildad.install --application my_app_name\n```\n\nFollow the instructions for modifying the `router.ex` file.\n\n```elixir\npost \"/jobs/engine/run\", Jobs.JobsController, :run_job_engine\n```\n\nFollow the instructions for modifying the `application.ex` file.\nBe sure to replace `MyApp.Repo` with the module of your repository.\n\n```elixir\n{Bildad.Job.JobKiller, repo: MyApp.Repo, check_time_in_seconds: 20},\n```\n\n> **NOTE**\n> You must call the run_job_engine periodically (via cron for example).\n\nYou must also create Job Templates for the jobs that you plan on running. They must \ncontain the string version of the Elixir module to run and a JSON schema definition\nso that the job context can be validated before a job is run.","ref":"readme.html#installation"},{"type":"extras","title":"Architecture - Bildad","doc":"* a database that works with Ecto\n* a phoenix controller that listens for requests and runs the job engine\n* a cron job to periodically run the jobs engine\n  * the request will only hit one server and the engine will run on that node\n* a job engine that runs on one node at a time\n  * this expires old jobs that have all timed out and cannot be killed on any node\n  * this runs new jobs in the queue that are available to run\n* a job killer task that is run on each node\n* job templates that know the name of the custom job Elixir module and the json schema used to validate the job context\n* custom jobs that have a `run_job` function that takes the job context\n* job templates that know the module name and have the schema for the job context\n\nDocumentation can be generated with [ExDoc](https://github.com/elixir-lang/ex_doc)\nand published on [HexDocs](https://hexdocs.pm). The docs can\nbe found at  .","ref":"readme.html#architecture"},{"type":"extras","title":"Changelog","doc":"# Changelog","ref":"changelog.html"},{"type":"extras","title":"v0.1.6 (2024-11-19) - Changelog","doc":"Current version. Recommended for use.","ref":"changelog.html#v0-1-6-2024-11-19"},{"type":"extras","title":"v0.1.5 (2024-11-18) - Changelog","doc":"Minor tweaks as the library is prepared. Not recommended to use this version.","ref":"changelog.html#v0-1-5-2024-11-18"},{"type":"extras","title":"v0.1.4 (2024-11-18) - Changelog","doc":"Minor tweaks as the library is prepared. Not recommended to use this version.","ref":"changelog.html#v0-1-4-2024-11-18"},{"type":"extras","title":"v0.1.3 (2024-11-18) - Changelog","doc":"Minor tweaks as the library is prepared. Not recommended to use this version.","ref":"changelog.html#v0-1-3-2024-11-18"},{"type":"extras","title":"v0.1.2 (2024-11-18) - Changelog","doc":"Minor tweaks as the library is prepared. Not recommended to use this version.","ref":"changelog.html#v0-1-2-2024-11-18"},{"type":"extras","title":"v0.1.1 (2024-11-18) - Changelog","doc":"Minor tweaks as the library is prepared. Not recommended to use this version.","ref":"changelog.html#v0-1-1-2024-11-18"},{"type":"extras","title":"v0.1.0 (2024-11-18) - Changelog","doc":"Initial release of Bildad.","ref":"changelog.html#v0-1-0-2024-11-18"}],"content_type":"text/markdown","producer":{"name":"ex_doc","version":[48,46,51,52,46,50]}}